#ifndef CAMMAINWINDOW_HPP
#define CAMMAINWINDOW_HPP

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <qlist.h>
#include <qmainwindow.h>
#include <qworkspace.h>

class CCamStreamMainWindow: public QMainWindow
{
   Q_OBJECT
private:
   QWorkspace *m_pWorkspace;

   void CloseAll();

private slots:
   void Quit();

   // Menu options
   void FileOpenNewViewer();

   // Misc
   void ShowTracer();

protected:
  void closeEvent(QCloseEvent *);

public:
   CCamStreamMainWindow();
   ~CCamStreamMainWindow();
};

#endif
